using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using HPS;

namespace hps_cs_samples
{
    public partial class Sample
    {
        public void Publish_Widgets(WindowKey wk, Canvas canvas, View view, Model model, SegmentKey modelKey)
        {
            String message =
             "Sample: Publish_Widgets" +
             "\nThis sample will show you how to:" +
             "\n  - Create a PDF file with widgets using HOOPS Publish" +
             "\n  - Output a file through Publish and check for IO exceptions" +
             "\n";

            String file_out = OUTPUT_FOLDER + "/publish_widgets.pdf";

            try
            {
                /* Sample: Publish_Widgets
                * This sample will show you how to:
                * - Create a PDF file with widgets using HOOPS Publish
                * - Output a file through Publish and check for IO exceptions
                *
                * Read more about the topics covered in this sample in our Programming Guide
                * - Integration with HOOPS Publish */
                HPS.Publish.PageKit pageKit = new HPS.Publish.PageKit();             // corresponds to a page inside the PDF
                HPS.Publish.DocumentKit documentKit = new HPS.Publish.DocumentKit(); // corresponds to the document itself as a whole

                // the text that will exist next to the checkbox
                HPS.Publish.TextKit text = new HPS.Publish.TextKit();
                text.SetText("checkbox");
                pageKit.AddText(text, new HPS.IntRectangle(140, 260, 400, 450));

                // setting up the checkbox
                HPS.Publish.CheckBoxKit checkBoxKit = HPS.Publish.CheckBoxKit.GetDefault();
                checkBoxKit.SetVisibility(true).
                    SetTextColor(new HPS.RGBColor(0, 0, 0)).
                    SetFillColor(new HPS.RGBColor(0.5f, 0.5f, 0.5f)).
                    SetName("cb1").
                    SetDefaultState(true);

                // checkboxes can be any size, as specified by the IntRectangle. this one will be fairly large
                pageKit.AddCheckBox(checkBoxKit, new HPS.IntRectangle(10, 120, 400, 450));

                // add a list button to the page
                HPS.Publish.ListBoxKit list_box_kit = new HPS.Publish.ListBoxKit();
                String[] displayed_contents = new String[] { "value1", "value2", "value3" };
                String[] exported_contents = new String[] { "e1", "e2", "e3" };

                list_box_kit.SetName("lb2").
                    SetContents(displayed_contents, exported_contents);
                pageKit.AddListBox(list_box_kit, new HPS.IntRectangle(10, 60, 300, 350));

                // add button to the page
                HPS.Publish.ButtonKit buttonKit = new HPS.Publish.ButtonKit();
                buttonKit.SetLabel("This is a page button")
                    .SetLabelPosition(HPS.Publish.Label.Position.OnTop)
                    .SetHighlighting(HPS.Publish.Highlighting.Mode.Push)
                    .SetVisibility(true)
                    .SetFont(HPS.Publish.Text.Font.Name.TimesRoman)
                    .SetFontSize(8)
                    .SetTextColor(new HPS.RGBColor(0, 0, 0))
                    .SetFillColor(new HPS.RGBColor(0.5f, 0.5f, 0.5f))
                    .SetName("execute_button"); // setting the name of the button is required!
                pageKit.AddButton(buttonKit, new HPS.IntRectangle(10, 120, 500, 550));

                // will print "hello world" to the Javascript console
                pageKit.SetJavaScriptActionByField("execute_button", "console.println(\"hello world\");", HPS.Publish.Source.Type.Code);

                documentKit.AddPage(pageKit);

                HPS.Publish.File.ExportPDF(documentKit, file_out, new HPS.Publish.ExportOptionsKit());
            }
            catch (HPS.IOException e)
            {
                System.Console.WriteLine(e.Message);
            }

            /*The next block of code shows you how to create TextKit for later usage
             * 1. Create a TextKit
             * 2. Set the textkit's formatting options such as position, region, background, and alignment
             * 3. Use the GetMaterialMappingControl to define the background's color properties
             * 4. Leave the TextKit uninserted to facilitate the error and success massage to be defined later */

            HPS.SegmentKey results_segment = modelKey.Subsegment();

            HPS.TextKit textKit = new HPS.TextKit();
            textKit.SetSize(0.02f, Text.SizeUnits.SubscreenRelative);
            HPS.Point[] point = { new HPS.Point(-0.95f, -0.65f, 10), new HPS.Point(0.95f, -0.65f, 10), new HPS.Point(0, -1, 10) };
            textKit.SetRegion(point, Text.RegionAlignment.Center, Text.RegionFitting.Left, false, false, true);
            textKit.SetBackground(true, "rounded box");
            textKit.SetAlignment(HPS.Text.Alignment.BottomLeft);
            results_segment.GetMaterialMappingControl().SetFaceColor(new RGBAColor(1, 1, 1));
            results_segment.GetMaterialMappingControl().SetEdgeColor(new RGBAColor(0, 0, 0));
            results_segment.GetVisibilityControl().SetEdges(true);

            //Success message formatting and setup
            string successMessage = 
                "\nThe sample output file has been saved here:\n   " +
                file_out;

            message += successMessage;

            textKit.SetText(message);
            results_segment.InsertText(textKit);
            view.Update();

        }
    }
}
